@@ -1,6 +1,4 @@
 /*
- * $Id: xmpp-servers.c,v 1.69 2011/01/31 15:10:43 cdidier Exp $
- *
  * Copyright (C) 2007 Colin DIDIER
  *
  * This program is free software; you can redistribute it and/or modify
@@ -244,6 +242,19 @@ lm_auth_cb(LmConnection *connection, gboolean success,
 	}
 	signal_emit("xmpp server status", 2, server,
 	    "Authenticated successfully.");
+
+	/* finnish connection process */
+	lookup_servers = g_slist_remove(lookup_servers, server);
+	g_source_remove(server->connect_tag);
+	server->connect_tag = -1;
+	server->show = XMPP_PRESENCE_AVAILABLE;
+	server->connected = TRUE;
+	if (server->timeout_tag) {
+		g_source_remove(server->timeout_tag);
+		server->timeout_tag = 0;
+	}
+	server_connect_finished(SERVER(server));
+	server->real_connect_time = server->connect_time;
 }
 
 /*
@@ -273,6 +284,8 @@ get_password()
 	/* Echo OFF, and assure we can prompt and get input */
 	to.c_lflag &= ~(ECHO | ECHOE | ECHOK | ECHONL);
 	to.c_lflag |= ICANON;
+	to.c_iflag &= ~IGNCR;
+	to.c_iflag |= ICRNL;
 	to.c_cc[VMIN] = 255;
 	tcsetattr(fd, TCSANOW, &to);
 
@@ -373,7 +386,7 @@ set_ssl(LmConnection *lmconn, GError **error, gpointer user_data,
 	ssl = lm_ssl_new(NULL, lm_ssl_cb, user_data, NULL);
 	lm_connection_set_ssl(lmconn, ssl);
 	if (use_starttls)
-		lm_ssl_use_starttls(ssl, TRUE, FALSE);
+		lm_ssl_use_starttls(ssl, TRUE, TRUE);
 	lm_ssl_unref(ssl);
 	return TRUE;
 }
@@ -556,28 +569,6 @@ sig_session_save(void)
 	disconnect_all();
 }
 
-static void
-sig_recv_iq(XMPP_SERVER_REC *server, LmMessage *lmsg, const int type,
-    const char *id, const char *from, const char *to)
-{
-	if (server->connected)
-		return;
-	if (type == LM_MESSAGE_SUB_TYPE_RESULT) {
-		/* we are fully connected when we receive the first iq stanza */
-		lookup_servers = g_slist_remove(lookup_servers, server);
-		g_source_remove(server->connect_tag);
-		server->connect_tag = -1;
-		server->show = XMPP_PRESENCE_AVAILABLE;
-		server->connected = TRUE;
-		if (server->timeout_tag) {
-			g_source_remove(server->timeout_tag);
-			server->timeout_tag = 0;
-		}
-		server_connect_finished(SERVER(server));
-		server->real_connect_time = server->connect_time;
-	}
-}
-
 void
 xmpp_servers_init(void)
 {
@@ -586,7 +577,6 @@ xmpp_servers_init(void)
 	signal_add_last("server connect failed", server_cleanup);
 	signal_add("server quit", sig_server_quit);
 	signal_add_first("session save", sig_session_save);
-	signal_add("xmpp recv iq", sig_recv_iq);
 
 	settings_add_int("xmpp", "xmpp_priority", 0);
 	settings_add_int("xmpp", "xmpp_priority_away", -1);
@@ -611,5 +601,4 @@ xmpp_servers_deinit(void)
 	signal_remove("server connect failed", server_cleanup);
 	signal_remove("server quit", sig_server_quit);
 	signal_remove("session save", sig_session_save);
-	signal_remove("xmpp recv iq", sig_recv_iq);
 }
